import Link from "next/link";
import { Button } from "@/components/ui/button";

export default function Home() {
  return (
    <div>
      {/* Hero Section */}
      <section className="bg-zinc-50 py-16 md:py-24">
        <div className="container mx-auto px-4 text-center">
          <h1 className="text-4xl md:text-5xl font-bold mb-6 text-zinc-900">
            Find Expert Tech Talent & AI Solutions
          </h1>
          <p className="text-lg md:text-xl text-zinc-600 max-w-3xl mx-auto mb-8">
            SiliconPin connects you with skilled human developers and advanced AI agents to help you build your next great product.
          </p>
          <div className="flex flex-col sm:flex-row gap-4 justify-center">
            <Link href="/hire-human-developer">
              <Button size="lg" className="w-full sm:w-auto">
                Hire a Human Developer
              </Button>
            </Link>
            <Link href="/hire-ai-agent">
              <Button size="lg" variant="outline" className="w-full sm:w-auto">
                Hire an AI Agent
              </Button>
            </Link>
          </div>
        </div>
      </section>

      {/* Services Overview */}
      <section className="py-16">
        <div className="container mx-auto px-4">
          <h2 className="text-3xl font-bold text-center mb-12 text-zinc-900">
            Our Services
          </h2>
          <div className="grid grid-cols-1 md:grid-cols-2 gap-8">
            {/* Human Developer Card */}
            <div className="border border-zinc-200 rounded-lg p-8 shadow-sm hover:shadow-md transition">
              <h3 className="text-2xl font-bold mb-4 text-zinc-900">Human Developers</h3>
              <p className="text-zinc-600 mb-6">
                Access skilled professionals across various technology specialties including web development, mobile apps, C/C++, Go, and more.
              </p>
              <Link href="/hire-human-developer">
                <Button variant="outline" className="w-full">
                  Learn More
                </Button>
              </Link>
            </div>

            {/* AI Agent Card */}
            <div className="border border-zinc-200 rounded-lg p-8 shadow-sm hover:shadow-md transition">
              <h3 className="text-2xl font-bold mb-4 text-zinc-900">AI Agents</h3>
              <p className="text-zinc-600 mb-6">
                Leverage cutting-edge AI solutions for tasks ranging from code generation to content creation and data analysis.
              </p>
              <Link href="/hire-ai-agent">
                <Button variant="outline" className="w-full">
                  Learn More
                </Button>
              </Link>
            </div>
          </div>
        </div>
      </section>

      {/* CTA Section */}
      <section className="bg-zinc-900 text-white py-16">
        <div className="container mx-auto px-4 text-center">
          <h2 className="text-3xl font-bold mb-6">Ready to start your project?</h2>
          <p className="text-zinc-300 max-w-2xl mx-auto mb-8">
            Whether you need human expertise or AI assistance, we have the right solution for your technical needs.
          </p>
          <Link href="/contact">
            <Button className="bg-white text-zinc-900 hover:bg-zinc-200">
              Contact Us
            </Button>
          </Link>
        </div>
      </section>
    </div>
  );
}
