"use client";

import Link from "next/link";
import { Button } from "@/components/ui/button";
import { useState } from "react";
import { Menu, X } from "lucide-react";

export default function Header() {
  const [isMenuOpen, setIsMenuOpen] = useState(false);

  const toggleMenu = () => {
    setIsMenuOpen(!isMenuOpen);
  };

  return (
    <header className="bg-white border-b border-gray-200">
      <div className="container mx-auto px-4 py-4">
        <div className="flex justify-between items-center">
          {/* Logo */}
          <Link href="/" className="flex items-center">
            <span className="text-xl font-bold text-zinc-900">SiliconPin</span>
          </Link>

          {/* Desktop Navigation */}
          <nav className="hidden md:flex space-x-6">
            <Link href="/" className="text-zinc-700 hover:text-zinc-900">
              Home
            </Link>
            <Link href="/hire-human-developer" className="text-zinc-700 hover:text-zinc-900">
              Hire a Human Developer
            </Link>
            <Link href="/hire-ai-agent" className="text-zinc-700 hover:text-zinc-900">
              Hire an AI Agent
            </Link>
            <Link href="/about" className="text-zinc-700 hover:text-zinc-900">
              About
            </Link>
          </nav>

          {/* Mobile menu button */}
          <div className="md:hidden">
            <Button variant="ghost" size="icon" onClick={toggleMenu}>
              {isMenuOpen ? <X size={24} /> : <Menu size={24} />}
            </Button>
          </div>
        </div>

        {/* Mobile Navigation */}
        {isMenuOpen && (
          <div className="md:hidden mt-4 py-4 border-t border-gray-200">
            <nav className="flex flex-col space-y-4">
              <Link
                href="/"
                className="text-zinc-700 hover:text-zinc-900"
                onClick={() => setIsMenuOpen(false)}
              >
                Home
              </Link>
              <Link
                href="/hire-human-developer"
                className="text-zinc-700 hover:text-zinc-900"
                onClick={() => setIsMenuOpen(false)}
              >
                Hire a Human Developer
              </Link>
              <Link
                href="/hire-ai-agent"
                className="text-zinc-700 hover:text-zinc-900"
                onClick={() => setIsMenuOpen(false)}
              >
                Hire an AI Agent
              </Link>
              <Link
                href="/about"
                className="text-zinc-700 hover:text-zinc-900"
                onClick={() => setIsMenuOpen(false)}
              >
                About
              </Link>
            </nav>
          </div>
        )}
      </div>
    </header>
  );
}
